<template>
  <div class="chart-wraper">
    <div class="chart" ref="chartContainer"></div>
  </div>
</template>

<script setup>
import * as echarts from "echarts";
import "./theme/custom";

import { onMounted, ref, watchEffect, nextTick, onBeforeUnmount } from "vue";

const props = defineProps({
  unit: {
    type: String,
  },
});

const chartContainer = ref(null);
let myChart = null;
let color = ["#0E7CE2", "#E271DE", "#00FFFF", "#F8456B", "#4AEAB0", "#FF8352"];

function getLinearColor(color0, color1) {
  return {
    type: "linear",
    x: 0,
    y: 0,
    x2: 0,
    y2: 1,
    colorStops: [
      {
        offset: 0,
        color: color0, // 0% 处的颜色
      },
      {
        offset: 1,
        color: color1, // 100% 处的颜色
      },
    ],
  };
}

function getOptions(xLabels = [], data = []) {
  let barColor = '#02a7f0';
  let maxColor = '#438D29';
  let minColor = '#DBD608';
  let legends = [];
  return {
    grid: {
      left: 60,
      right: "1%",
    },
    // legend: {
    //   x: "22%",
    //   top: "8%",
    //   textStyle: {
    //     color: "#ffffff",
    //   },
    //   data: xLabels,
    // },
    tooltip: {
      trigger: "axis",
      axisPointer: {
        type: "shadow",
      },
    },
    xAxis: {
      type: "category",
      data: xLabels,
    },
    yAxis: {
      type: "value",
      name: props.unit ? `单位: ${props.unit}` : "",
      min: function (data) {
        let min = data.min;
        if (min == Infinity) {
          return 0;
        }
        return Number((min - min * 0.2).toFixed(2));
      },
      max: function (data) {
        let max = data.max;
        if (max == -Infinity) {
          max = 1;
        }
        return Number((max + max * 0.2).toFixed(2));
      },
    },
    series: [
      {
        color,
        data,
        type: "bar",
        // barWidth: 20,
        itemStyle: {
                 color: (params) => {
            // console.log('params', params, data, '=============');
            let max = Math.max(...data);
            let min = Math.min(...(data.filter((item) => item != 0)));
            let val = params.value;
            // console.log('min, max, val', min, max, val, '=============');
            
            if (val == min) {
              return minColor;
            } else if (val == max) {
              return maxColor;
            }
            return barColor;
          },
        },
        // label: {
        //   normal: {
        //     show: true,
        //     position: "top",
        //     textStyle: {
        //       color: "#fff",
        //       fontSize: 20,
        //     },
        //   },
        // },
        showBackground: true,
        backgroundStyle: {
          color: "rgba(0, 0, 0, 0.1)",
        },
      },
    ],
  };
}

function initChart() {
  if (chartContainer.value) {
    myChart = echarts.init(chartContainer.value, "custom");

    let option = getOptions();
    myChart.setOption(option);

    // 监听窗口变化重新渲染图表
    window.addEventListener("resize", () => {
      myChart.resize();
    });
  }
}

function updateChart(xLabels, datas) {
  let option = getOptions(xLabels, datas);
  myChart.setOption(option);
}

function resize() {
  myChart.resize();
}

onMounted(() => {
  initChart();
});

watchEffect(() => {
  // 如果需要基于某些响应式数据更新图表，可以在这里处理
});

onBeforeUnmount(() => {
  if (myChart) {
    myChart.dispose();
  }
});

defineExpose({
  updateChart,
  resize,
});
</script>

<style scoped lang="less">
.chart-wraper {
  height: 100%;
  position: relative;
  .chart {
    position: absolute;
    left: 0;
    top: 0;
    right: 0;
    bottom: 0;
  }
}
</style>
